\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{ituthesis}[2012/09/06 A document class for IT University of Copenhagen theses and reports]

%% This document class is based on memoir
\LoadClass[a4paper, showtrims, 12pt, twoside, openright, onecolumn, final]{memoir}

\RequirePackage[english]{babel}

%% Graphics
\RequirePackage{tikz}
\usetikzlibrary{positioning}
\usetikzlibrary{calc}

%% Get \maketitle to produce something nice for ITU
\setlength{\droptitle}{5cm}

%% More comprehensive math
\usepackage{amsmath}
\usepackage{amsfonts}

%% Better fonts
\usepackage[T1]{fontenc}
\usepackage{textcomp}

\usepackage{palatino}
\linespread{1.1} % palatino needs a bit more space
\usepackage[sc]{mathpazo} % math font that matches palatino
% TODO: Consider osf in mathpazo

% Use paratype sans narrow for sans-serif fonts
\usepackage{PTSansNarrow}

% Luxi Mono is an attractive typewriter font with bold and italic
\usepackage[scaled]{luximono}

%% Abstract sans serif
\renewcommand{\abstractnamefont}{\Large\sffamily}

%% TOC sans serif

\renewcommand{\cftpartfont}{\normalfont\sffamily\bfseries}
\renewcommand{\cftchapterfont}{\normalfont\sffamily}
\renewcommand{\cftsectionfont}{\normalfont\sffamily}
\renewcommand{\cftchapterpagefont}{\normalfont\sffamily}
\renewcommand{\cftsectionpagefont}{\normalfont\sffamily}
\setsecnumdepth{chapter}

%% Parts sans serif
\renewcommand{\parttitlefont}{\Huge\sffamily}
\renewcommand{\partnamefont}{\Huge\sffamily}
\renewcommand{\partnumfont}{\Huge\sffamily}

%% Chapter headers sans serif
\newcommand{\joint}[1]{\def\thejoint{#1}}
\newcommand{\originally}[1]{\def\theorigin{#1}}

\makeatletter
\def\ori{\@ifundefined{theorigin}{}{Originally published in: \theorigin}}
\def\joi{\@ifundefined{thejoint}{}{Joint work with: \thejoint}}
\makeatother

\makechapterstyle{ituchapter}{%
  \renewcommand{\chaptitlefont}{\normalfont\HUGE\sffamily\raggedright} % set sans serif chapter title font
  \renewcommand{\chapnamefont}{\normalfont\Large\sffamily\raggedright}
  \renewcommand{\chapnumfont}{\normalfont\Large\sffamily\raggedright} % set sans serif chapter number Font
  \renewcommand{\afterchaptertitle}{\par\nobreak \vskip 15pt \small \normalfont\sffamily{\ori \vskip 3pt \joi} \vskip \afterchapskip \global\let\theorigin\relax \global\let\thejoint\relax}
}

\chapterstyle{ituchapter} % try also: default , section , hangnum , companion , article, demo

\renewcommand*{\footnoterule}{\vskip 10pt}

%% Section headers sans serif
%\hangsecnum % hang the section numbers into the margin to match \chapterstyle{hangnum}
\maxsecnumdepth{subsection} % number subsections

\setsecheadstyle{\Large\sffamily\raggedright} % set sans serif section font
\setsubsecheadstyle{\large\sffamily\raggedright} % set sans serif subsection font

%% Captions sans serif
\captionnamefont{\small\sffamily\itshape}
\captiontitlefont{\small\sffamily\itshape}
%\subcaptionfont{\footnotesize\sffamily}
%\subcaptionlabelfont{\footnotesize\sffamily}

%% Page headings
\nouppercaseheads
\copypagestyle{ituheadings}{headings}
\makeevenhead{ituheadings}{{\small\sffamily\thepage}}{}{{\small\normalfont\sffamily\leftmark}}
\makeoddhead{ituheadings}{{\small\normalfont\sffamily\rightmark}}{}{{\small\sffamily\thepage}}
\pagestyle{ituheadings}

\makeevenfoot{plain}{}{\sffamily\thepage}{}
\makeoddfoot{plain}{}{\sffamily\thepage}{}

\newlength{\linespace}
\setlength{\linespace}{\baselineskip}

% no page number on chapter and part page!
\aliaspagestyle{chapter}{empty}
\aliaspagestyle{part}{empty}

%%%% for the title page and approval page.
\newlength{\toptafiddle}
\setlength{\toptafiddle}{2\linespace}
\newlength{\bottafiddle}
\setlength{\bottafiddle}{0pt}
\newlength{\topfiddle}
\setlength{\topfiddle}{\toptafiddle}
\newlength{\botfiddle}
\setlength{\botfiddle}{\onelineskip}

% your title
\newcommand{\settitle}[1]{\def\itutitle{#1}}
%your subtitle
\newcommand{\setsubtitle}[1]{\def\itusubtitle{#1}}
% you
\newcommand{\setauthor}[1]{\def\ituauthor{#1}}
\newcommand{\setemail}[1]{\def\ituemail{#1}}
% your supervisor
\newcommand{\setsupervisor}[1]{\def\itusupervisor{#1}}
\newcommand{\setextrasupervisor}[1]{\def\itusupervisorextra{#1}}

% your evaluation committee
\newcommand{\setevaluationchair}[1]{\def\ituevaluationchair{#1}}
\newcommand{\setevaluationchairaffiliation}[1]{\def\ituevaluationchairaffiliation{#1}}
\newcommand{\setevaluationone}[1]{\def\ituevaluationone{#1}}
\newcommand{\setevaluationoneaffiliation}[1]{\def\ituevaluationoneaffiliation{#1}}
\newcommand{\setevaluationtwo}[1]{\def\ituevaluationtwo{#1}}
\newcommand{\setevaluationtwoaffiliation}[1]{\def\ituevaluationtwoaffiliation{#1}}

% submission date
\newcommand{\setdate}[1]{\def\itudate{#1}}

\makeatletter
\def\sups{\@ifundefined{itusupervisorextra}{Advisor}{Advisors}}
\makeatother


%%% typesets the TITLE page
\newcommand{\thetitlepage}{
  \thispagestyle{empty}
  \insertchapterspace
  \chapterheadstart
  \begin{center}
{\sffamily\Huge {Incremental Interactive Verification of the}} \\
\vspace*{.3cm}
{\sffamily\Huge {Correctness of Object-Oriented Software}} \\
\vspace*{.6cm}
{\sffamily\Large \itusubtitle} \\
\vspace*{2cm}
{\sffamily\Large \ituauthor}
  \end{center}
  \begin{tikzpicture}[remember picture,overlay,line width=0mm,shift=(current page.south east)]
    \node[anchor=south east] (logo) at (-2.5cm,2.5cm) {
        \includegraphics[width=7cm]{itulogo}
    };
  \end{tikzpicture}
}

\newcommand{\thethirdpage}{
  \thispagestyle{empty}
  \insertchapterspace
  \chapterheadstart
  \noindent
A dissertation submitted to the PhD school at the IT University of\\
Copenhagen for the degree of Doctor of Philosophy.\\

\noindent Submitted: \itudate, Copenhagen\\
Defended: 11th October 2013, Copenhagen\\
Final version: December 2013, Copenhagen\\
\\


\vspace*{4cm}

\noindent
{\normalfont\sffamily \sups}: \\
\hspace*{1em} \itusupervisor , IT University of Copenhagen, Denmark \\
\hspace*{1em} \itusupervisorextra , Aarhus University, Denmark

\vspace*{1.5cm}

\noindent
{\normalfont\sffamily Evaluation committee}: \\
\hspace*{1em} \ituevaluationchair , \ituevaluationchairaffiliation \\
\hspace*{1em} \ituevaluationone , \ituevaluationoneaffiliation \\
\hspace*{1em} \ituevaluationtwo , \ituevaluationtwoaffiliation \\

%\vspace*{3.5cm}
%\noindent
%This revision includes improvements suggested by the evaluation\\
%committee.
}
